import { createSerialOperation } from '@deep-foundation/deeplinks/imports/gql/index.js';
import createDebugMessages from 'debug';
import { Package } from './package.js';
/**
  * Gets serial operations to insert Motion
  *
  * @example
 ```ts
 const serialOperations = await getMotionInsertSerialOperations({
   deep,
   info
 });
 await deep.serial({
   operations: serialOperations
 })
 ```
  */
export async function getMotionInsertSerialOperations(param) {
    const serialOperations = [];
    const { deep, info, containValue, containerLinkId, } = param;
    const $package = new Package({ deep });
    const debug = createDebugMessages(`${$package.name}:getMotionInsertSerialOperations`);
    debug({ param });
    const reservedLinkIds = await getReservedLinkIds();
    debug({ reservedLinkIds });
    const { containLinkId, motionLinkId } = reservedLinkIds;
    const typeLinkIds = await getTypeLinkIds();
    debug({ typeLinkIds });
    const { containTypeLinkId, motionTypeLinkId } = typeLinkIds;
    const motionInsertSerialOperation = createSerialOperation({
        type: 'insert',
        table: 'links',
        objects: {
            id: motionLinkId,
            type_id: motionTypeLinkId,
        },
    });
    debug({ motionInsertSerialOperation });
    serialOperations.push(motionInsertSerialOperation);
    const valueOfMotionInsertSerialOperation = createSerialOperation({
        type: 'insert',
        table: 'objects',
        objects: {
            link_id: motionLinkId,
            value: info,
        },
    });
    debug({ valueOfMotionInsertSerialOperation });
    serialOperations.push(valueOfMotionInsertSerialOperation);
    if (containerLinkId !== null) {
        const containInsertSerialOperation = createSerialOperation({
            type: 'insert',
            table: 'links',
            objects: {
                type_id: containTypeLinkId,
                from_id: containerLinkId || deep.linkId,
                to_id: motionLinkId,
            },
        });
        debug({ containInsertSerialOperation });
        serialOperations.push(containInsertSerialOperation);
        const valueOfContainInsertSerialOperation = createSerialOperation({
            type: 'insert',
            table: 'strings',
            objects: {
                link_id: containLinkId,
                value: containValue,
            },
        });
        debug({ valueOfContainInsertSerialOperation });
        serialOperations.push(valueOfContainInsertSerialOperation);
    }
    debug({ serialOperations });
    return serialOperations;
    async function getReservedLinkIds() {
        let result = {
            containLinkId: 0,
            motionLinkId: 0,
        };
        const linksToReserveCount = Object.keys(result).length -
            Object.keys(param.reservedLinkIds || {}).length;
        const reservedLinkIds = linksToReserveCount > 0 ? await deep.reserve(linksToReserveCount) : [];
        result = {
            containLinkId: param.reservedLinkIds?.containLinkId ?? reservedLinkIds.pop(),
            motionLinkId: param.reservedLinkIds?.motionLinkId ?? reservedLinkIds.pop(),
        };
        return result;
    }
    async function getTypeLinkIds() {
        const result = {
            containTypeLinkId: param.typeLinkIds?.containTypeLinkId ||
                (await deep.id('@deep-foundation/core', 'Contain')),
            motionTypeLinkId: param.typeLinkIds?.motionTypeLinkId ||
                await $package.Motion.id(),
        };
        return result;
    }
}
