import { DeepClient } from '@deep-foundation/deeplinks/imports/client.js';
import { MotionInfo } from '../motion-info.js';
/**
 * Returns a subscription handler for the acceleration/orientation event
 *
 * @remarks It is not recommended to use this function directly. Instead use {@link WithUseAccelerationSubscription} or {@link WithUseOrientationSubscription}
 *
 * @example
 * #### Handle acceleration event
```ts
const accelerationHandlerFunction = getSubscriptionHandler({
  deep,
  containerLinkId,
});
const accelerationHandler = Motion.addListener(
  'accel',
  accelerationHandlerFunction
);
return () => {
  accelerationHandler.remove();
};
```
  * #### Handle orientation event
```ts
useEffect(() => {
  const accelerationHandlerFunction = getSubscriptionHandler({
      deep,
      containerLinkId,
  })
  const orientationHandler = Motion.addListener('orientation', (event) => {
      accelerationHandlerFunction({
        rotationRate: event
      })
  });
  return () => {
      orientationHandler.remove();
  }
}, [deep, containerLinkId])
```
 */
export declare function getSubscriptionHandler(param: GetSubscriptionHandlerParam): (paramInfo: MotionInfo) => Promise<void>;
export interface GetSubscriptionHandlerParam {
    /**
     * A Deep client instance
     */
    deep: DeepClient;
    /**
     * A container link id
     */
    containerLinkId: number;
}
