import { Motion } from '@capacitor/motion';
import { useEffect } from 'react';
import createDebugMessages from 'debug';
import { getSubscriptionHandler } from '../get-subscription-handler.js';
import { Package } from '../../package.js';
/**
 * This hook subscribes to the acceleration event and saves the data to Deep
 *
 * @remarks
 * It is not recommended to use this hook directly. Instead of {@link WithUseAccelerationSubscription}
 *
 * @example
```ts
useAccelerationSubscription({
  deep,
  containerLinkId
})
```
 */
export function useAccelerationSubscription(param) {
    const { deep, containerLinkId = deep.linkId } = param;
    const $package = new Package({ deep });
    const debug = createDebugMessages(`${$package.name}:useAccelerationSubscription`);
    debug({ param });
    useEffect(() => {
        const accelerationHandlerFunction = getSubscriptionHandler({
            deep,
            containerLinkId,
        });
        const accelerationHandler = Motion.addListener('accel', accelerationHandlerFunction);
        debug({ accelerationHandler });
        return () => {
            accelerationHandler.remove();
        };
    }, [deep, containerLinkId]);
}
